/* ver.A.04.01(ASTROBOY) */


#include "version.h"


VERSION machine_code_version = {
	"MA.code",
	"Mac.Carbon.Interface",
	"(C) 2000-2004 Hirohisa Mori And GB-group",
	"ver.A.04.01(ASTROBOY)",
	2004,3,23,
	0,
	"machine (Mac Carbon) dependent library ",
};

